@@ -7,7 +7,7 @@ use Carp qw(croak confess);
 use POSIX qw(strftime);
 use Time::HiRes qw(time);
 
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 
 BEGIN {
 
@@ -140,7 +140,7 @@ sub file {
     $mode = 'a' if ! defined $mode;
     my $op = $mode =~ /^a/ ? '>>' : '>';
 
-    open $self->{fh}, $op, $file or die "can't open log file for writing: $!";
+    open $self->{fh}, $op, $file or croak "can't open log file for writing: $!";
     $self->{file} = $file;
 
     return $self->{file};
@@ -151,7 +151,7 @@ sub name {
     return $self->{name};
 }
 sub timestamp {
-	my $t = time;
+    my $t = time;
     my $date = strftime "%Y-%m-%d %H:%M:%S", localtime $t;
     $date .= sprintf ".%03d", ($t-int($t))*1000; # without rounding
     return $date;
@@ -245,6 +245,8 @@ sub fatal {
     confess("\n" . $self->_0("$msg"));
 }
 sub _generate_entry {
+    # builds/formats the log entry line
+
     my $self = shift;
     my %entry = @_;
 
@@ -254,7 +256,7 @@ sub _generate_entry {
 
     my $subs = $self->_sub_names;
     if (! grep { $label eq $_ } @$subs){
-        croak "_generate_entry() requires a sub/label name as its first param\n";
+        croak "_generate_entry() requires a label => sub/label param\n";
     }
 
     $label =~ s/_//;
@@ -282,6 +284,8 @@ sub _generate_entry {
     }
 }
 sub _levels {
+    # manages the level labels
+
     my ($self, $labels) = @_;
 
     if (ref $labels eq 'ARRAY'){
@@ -305,6 +309,8 @@ sub _levels {
     return %{ $self->{labels} };
 }
 sub _log_only {
+    # are we logging only one level or not?
+
     my ($self, $level) = @_;
     if (defined $level && $level == -1){
         $self->{log_only} = undef;
@@ -320,11 +326,12 @@ __END__
 
 =head1 NAME
 
-Logging::Simple - Simple logging with customizable display and labels
+Logging::Simple - Simple debug logging by number, with customizable labels and
+formatting
 
 =for html
-<a href="http://travis-ci.org/stevieb9/p5-logging-simple"><img src="https://secure.travis-ci.org/stevieb9/p5-logging-simple.png"/>
-<a href='https://coveralls.io/github/stevieb9/p5-logging-simple?branch=master'><img src='https://coveralls.io/repos/stevieb9/p5-logging-simple/badge.svg?branch=master&service=github' alt='Coverage Status' /></a>
+<a href="http://travis-ci.org/stevieb9/logging-simple"><img src="https://secure.travis-ci.org/stevieb9/logging-simple.png"/>
+<a href='https://coveralls.io/github/stevieb9/logging-simple?branch=master'><img src='https://coveralls.io/repos/stevieb9/logging-simple/badge.svg?branch=master&service=github' alt='Coverage Status' /></a>
 
 =head1 SYNOPSIS
 
@@ -352,20 +359,30 @@ Logging::Simple - Simple logging with customizable display and labels
     $log->_0("this will go to file");
     $log->file(0); # back to STDOUT
 
+    # log to a "memory file"
+
+    my $memfile;
+    $log->file(\$memfile);
+
     # don't print, return instead
 
     $log->print(0);
-    my $log_entry = $log->info("print disabled");
+    my $log_entry = $log->_2("print disabled");
+
+    # send in your own log entry labels for the levels. They will be mapped
+    # 0 through 7
+
+    $log->labels([qw(emerg alert crit error warn notice info debug)]);
 
     # using a child log
 
     my $log = Logging::Simple->new(name => 'main');
-    $log->_0("parent log";
+    $log->_0("parent log");
 
     testing();
 
     sub testing {
-        $log = $log->child('testing()');
+        my $log = $log->child('testing()');
         $log->_4("child log");
     }
     __END__
@@ -389,21 +406,22 @@ custom labels.
 =head2 Logging entry format
 
 By default, log entries appear as such, with a timestamp, the name of the
-facility, the name (if specified in the constructor) and finally the actual
-log entry message.
+facility, the name (if previously set) and finally the actual log entry
+message.
 
-    [2016-03-17 17:01:21.959][lvl 6][whatever] $log->_6() example output
+    [2016-03-17 17:01:21.959][lvl 6][whatever] example output
 
 All of the above tags can be enabled/disabled programatically at any time, and
-there are others that are not enabled by default. See L<display> method for
+there are others that are not enabled by default. You can even add your own
+custom tag. See the C<display()> method in L</CONFIGURATION METHODS> for further
 details.
 
-=head1 INITIALIZATION METHODS
+=head1 CONFIGURATION METHODS
 
 =head2 new(%args)
 
-Builds and returns a new C<Logging::Simple> object. All arguments are optional, and
-they can all be set using accessor methods after instantiation. These params
+Builds and returns a new C<Logging::Simple> object. All arguments are optional,
+and they can all be set using accessor methods after instantiation. These params
 are:
 
     name        => $str  # optional, default is undef
@@ -413,8 +431,9 @@ are:
     print       => $bool # default on, enable/disable output and return instead
     display     => $bool # default on, enable/disable log message tags
 
-Each of the above parameters have associated methods described below with more
-details.
+=head2 name($name)
+
+Returns the name of the log, if available. Send in a string to set it.
 
 =head2 level($num)
 
@@ -424,7 +443,8 @@ the C<LS_LEVEL> environment variable, at any time. the next method call
 regardless of what it is will set it appropriately.
 
 You can also send in C<-1> as a level to disable all levels, or send in the
-level prepended with a C<=> to log *only* that level (eg: C<$log->level('=3')>.
+level prepended with a C<=> to log *only* that level (eg:
+C<$log-E<gt>level('=3')>.
 
 =head2 file('file.log', 'mode')
 
@@ -450,7 +470,7 @@ You can also send in 1 to enable all of the tags, or 0 to disable them all.
 =head2 labels($list|0)
 
 Send in an array reference of eight custom labels. We will map them in order to
-the levels 0 through 7.
+the levels 0 through 7, and your labels will be displayed in the log entries.
 
 Send in C<0> to disable your custom labels.
 
@@ -485,11 +505,12 @@ from there.
 All log facilities are called by their corresponing numbered sub, eg:
 
     $log->_0("level 0 entry");
+    ...
     $log->_7("level 7 entry");
 
 =head2 fatal($msg)
 
-Log the message, along with the trace C<confess()> produces, and die
+Log the message, along with the trace C<confess()> produces, and croak's
 immediately.
 
 =head1 HELPER METHODS
@@ -514,11 +535,11 @@ Steve Bertrand, C<< <steveb at cpan.org> >>
 =head1 BUGS
 
 Please report any bugs or feature requests to
-L<https://github.com/stevieb9/p5-logging-simple/issues>
+L<https://github.com/stevieb9/logging-simple/issues>
 
 =head1 REPOSITORY
 
-L<https://github.com/stevieb9/p5-logging-simple>
+L<https://github.com/stevieb9/logging-simple>
 
 =head1 BUILD RESULTS (THIS VERSION)
 
